@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "7dd58c7eed20db09ecc931433ffffd31a7e940ed",
-  "branchName": "release-client-6.1.6",
-  "buildTime": "2024-07-26 03:01:56 GMT",
-  "buildVersion": "1.0.982",
+  "commitId": "c39ac0850442aaf624ab4d8438c883d9aa313c8f",
+  "branchName": "release-client-6.x",
+  "buildTime": "2024-12-13 01:26:17 GMT",
+  "buildVersion": "1.0.1460",
   "css": [
-    "@zoom/client-calendar-desktop/static/css/chunk-vendors.49e8f34d.css",
-    "@zoom/client-calendar-desktop/static/css/app.bd7c05bf.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
+    "@zoom/client-scheduler/static/css/index.60f74ba0.css"
   ],
   "js": [
-    "@zoom/client-calendar-desktop/static/js/chunk-vendors.a7965a68.js",
-    "@zoom/client-calendar-desktop/static/js/app.fa7d841d.js"
+    "@zoom/client-scheduler/chunk-vendors.83594c8447326f77f45b.js",
+    "@zoom/client-scheduler/index.83594c8447326f77f45b.js"
   ],
-  "key": "@zoom/client-calendar-desktop"
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
